# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class IncidentViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'geo_hazard_tid': 'int',
        'geo_hazard_name': 'str',
        'activity_influenced_tid': 'int',
        'activity_influenced_name': 'str',
        'damage_extent_tid': 'int',
        'damage_extent_name': 'str',
        'forecast_accurate_tid': 'int',
        'forecast_accurate_name': 'str',
        'dt_end_time': 'datetime',
        'incident_header': 'str',
        'incident_ingress': 'str',
        'incident_text': 'str',
        'comment': 'str',
        'incident_ur_ls': 'list[UrlViewModel]'
    }

    attribute_map = {
        'geo_hazard_tid': 'GeoHazardTID',
        'geo_hazard_name': 'GeoHazardName',
        'activity_influenced_tid': 'ActivityInfluencedTID',
        'activity_influenced_name': 'ActivityInfluencedName',
        'damage_extent_tid': 'DamageExtentTID',
        'damage_extent_name': 'DamageExtentName',
        'forecast_accurate_tid': 'ForecastAccurateTID',
        'forecast_accurate_name': 'ForecastAccurateName',
        'dt_end_time': 'DtEndTime',
        'incident_header': 'IncidentHeader',
        'incident_ingress': 'IncidentIngress',
        'incident_text': 'IncidentText',
        'comment': 'Comment',
        'incident_ur_ls': 'IncidentURLs'
    }

    def __init__(self, geo_hazard_tid=None, geo_hazard_name=None, activity_influenced_tid=None, activity_influenced_name=None, damage_extent_tid=None, damage_extent_name=None, forecast_accurate_tid=None, forecast_accurate_name=None, dt_end_time=None, incident_header=None, incident_ingress=None, incident_text=None, comment=None, incident_ur_ls=None):  # noqa: E501
        """IncidentViewModel - a model defined in Swagger"""  # noqa: E501
        self._geo_hazard_tid = None
        self._geo_hazard_name = None
        self._activity_influenced_tid = None
        self._activity_influenced_name = None
        self._damage_extent_tid = None
        self._damage_extent_name = None
        self._forecast_accurate_tid = None
        self._forecast_accurate_name = None
        self._dt_end_time = None
        self._incident_header = None
        self._incident_ingress = None
        self._incident_text = None
        self._comment = None
        self._incident_ur_ls = None
        self.discriminator = None
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if geo_hazard_name is not None:
            self.geo_hazard_name = geo_hazard_name
        if activity_influenced_tid is not None:
            self.activity_influenced_tid = activity_influenced_tid
        if activity_influenced_name is not None:
            self.activity_influenced_name = activity_influenced_name
        if damage_extent_tid is not None:
            self.damage_extent_tid = damage_extent_tid
        if damage_extent_name is not None:
            self.damage_extent_name = damage_extent_name
        if forecast_accurate_tid is not None:
            self.forecast_accurate_tid = forecast_accurate_tid
        if forecast_accurate_name is not None:
            self.forecast_accurate_name = forecast_accurate_name
        if dt_end_time is not None:
            self.dt_end_time = dt_end_time
        if incident_header is not None:
            self.incident_header = incident_header
        if incident_ingress is not None:
            self.incident_ingress = incident_ingress
        if incident_text is not None:
            self.incident_text = incident_text
        if comment is not None:
            self.comment = comment
        if incident_ur_ls is not None:
            self.incident_ur_ls = incident_ur_ls

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this IncidentViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this IncidentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this IncidentViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this IncidentViewModel.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def geo_hazard_name(self):
        """Gets the geo_hazard_name of this IncidentViewModel.  # noqa: E501


        :return: The geo_hazard_name of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._geo_hazard_name

    @geo_hazard_name.setter
    def geo_hazard_name(self, geo_hazard_name):
        """Sets the geo_hazard_name of this IncidentViewModel.


        :param geo_hazard_name: The geo_hazard_name of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._geo_hazard_name = geo_hazard_name

    @property
    def activity_influenced_tid(self):
        """Gets the activity_influenced_tid of this IncidentViewModel.  # noqa: E501


        :return: The activity_influenced_tid of this IncidentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._activity_influenced_tid

    @activity_influenced_tid.setter
    def activity_influenced_tid(self, activity_influenced_tid):
        """Sets the activity_influenced_tid of this IncidentViewModel.


        :param activity_influenced_tid: The activity_influenced_tid of this IncidentViewModel.  # noqa: E501
        :type: int
        """

        self._activity_influenced_tid = activity_influenced_tid

    @property
    def activity_influenced_name(self):
        """Gets the activity_influenced_name of this IncidentViewModel.  # noqa: E501


        :return: The activity_influenced_name of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._activity_influenced_name

    @activity_influenced_name.setter
    def activity_influenced_name(self, activity_influenced_name):
        """Sets the activity_influenced_name of this IncidentViewModel.


        :param activity_influenced_name: The activity_influenced_name of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._activity_influenced_name = activity_influenced_name

    @property
    def damage_extent_tid(self):
        """Gets the damage_extent_tid of this IncidentViewModel.  # noqa: E501


        :return: The damage_extent_tid of this IncidentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._damage_extent_tid

    @damage_extent_tid.setter
    def damage_extent_tid(self, damage_extent_tid):
        """Sets the damage_extent_tid of this IncidentViewModel.


        :param damage_extent_tid: The damage_extent_tid of this IncidentViewModel.  # noqa: E501
        :type: int
        """

        self._damage_extent_tid = damage_extent_tid

    @property
    def damage_extent_name(self):
        """Gets the damage_extent_name of this IncidentViewModel.  # noqa: E501


        :return: The damage_extent_name of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._damage_extent_name

    @damage_extent_name.setter
    def damage_extent_name(self, damage_extent_name):
        """Sets the damage_extent_name of this IncidentViewModel.


        :param damage_extent_name: The damage_extent_name of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._damage_extent_name = damage_extent_name

    @property
    def forecast_accurate_tid(self):
        """Gets the forecast_accurate_tid of this IncidentViewModel.  # noqa: E501


        :return: The forecast_accurate_tid of this IncidentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._forecast_accurate_tid

    @forecast_accurate_tid.setter
    def forecast_accurate_tid(self, forecast_accurate_tid):
        """Sets the forecast_accurate_tid of this IncidentViewModel.


        :param forecast_accurate_tid: The forecast_accurate_tid of this IncidentViewModel.  # noqa: E501
        :type: int
        """

        self._forecast_accurate_tid = forecast_accurate_tid

    @property
    def forecast_accurate_name(self):
        """Gets the forecast_accurate_name of this IncidentViewModel.  # noqa: E501


        :return: The forecast_accurate_name of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._forecast_accurate_name

    @forecast_accurate_name.setter
    def forecast_accurate_name(self, forecast_accurate_name):
        """Sets the forecast_accurate_name of this IncidentViewModel.


        :param forecast_accurate_name: The forecast_accurate_name of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._forecast_accurate_name = forecast_accurate_name

    @property
    def dt_end_time(self):
        """Gets the dt_end_time of this IncidentViewModel.  # noqa: E501


        :return: The dt_end_time of this IncidentViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_end_time

    @dt_end_time.setter
    def dt_end_time(self, dt_end_time):
        """Sets the dt_end_time of this IncidentViewModel.


        :param dt_end_time: The dt_end_time of this IncidentViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_end_time = dt_end_time

    @property
    def incident_header(self):
        """Gets the incident_header of this IncidentViewModel.  # noqa: E501


        :return: The incident_header of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._incident_header

    @incident_header.setter
    def incident_header(self, incident_header):
        """Sets the incident_header of this IncidentViewModel.


        :param incident_header: The incident_header of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._incident_header = incident_header

    @property
    def incident_ingress(self):
        """Gets the incident_ingress of this IncidentViewModel.  # noqa: E501


        :return: The incident_ingress of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._incident_ingress

    @incident_ingress.setter
    def incident_ingress(self, incident_ingress):
        """Sets the incident_ingress of this IncidentViewModel.


        :param incident_ingress: The incident_ingress of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._incident_ingress = incident_ingress

    @property
    def incident_text(self):
        """Gets the incident_text of this IncidentViewModel.  # noqa: E501


        :return: The incident_text of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._incident_text

    @incident_text.setter
    def incident_text(self, incident_text):
        """Sets the incident_text of this IncidentViewModel.


        :param incident_text: The incident_text of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._incident_text = incident_text

    @property
    def comment(self):
        """Gets the comment of this IncidentViewModel.  # noqa: E501


        :return: The comment of this IncidentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this IncidentViewModel.


        :param comment: The comment of this IncidentViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def incident_ur_ls(self):
        """Gets the incident_ur_ls of this IncidentViewModel.  # noqa: E501


        :return: The incident_ur_ls of this IncidentViewModel.  # noqa: E501
        :rtype: list[UrlViewModel]
        """
        return self._incident_ur_ls

    @incident_ur_ls.setter
    def incident_ur_ls(self, incident_ur_ls):
        """Sets the incident_ur_ls of this IncidentViewModel.


        :param incident_ur_ls: The incident_ur_ls of this IncidentViewModel.  # noqa: E501
        :type: list[UrlViewModel]
        """

        self._incident_ur_ls = incident_ur_ls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncidentViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CreateRegistrationRequestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'geo_hazard_tid': 'int',
        'dt_obs_time': 'datetime',
        'observer_guid': 'str',
        'email': 'bool',
        'obs_location_id': 'int',
        'observer_group_id': 'int',
        'comment': 'str',
        'source_tid': 'int',
        'avalanche_activity_obs': 'list[AvalancheActivityObsDto]',
        'avalanche_activity_obs2': 'list[AvalancheActivityObs2Dto]',
        'avalanche_danger_obs': 'list[AvalancheDangerObsDto]',
        'avalanche_eval_problem2': 'list[AvalancheEvalProblem2Dto]',
        'avalanche_evaluation3': 'AvalancheEvaluation3Dto',
        'avalanche_obs': 'AvalancheObsDto',
        'compression_test': 'list[CompressionTestDto]',
        'danger_obs': 'list[DangerObsDto]',
        'general_observation': 'GeneralObservationEditModel',
        'ice_cover_obs': 'IceCoverObsDto',
        'ice_thickness': 'IceThicknessDto',
        'incident': 'IncidentDto',
        'land_slide_obs': 'LandSlideObsDto',
        'obs_location': 'ObsLocationDto',
        'picture': 'list[PictureRequestDto]',
        'snow_cover_obs': 'SnowCoverObsDto',
        'snow_profile': 'PictureRequestDto',
        'snow_profile2': 'SnowProfileDto',
        'snow_surface_observation': 'SnowSurfaceObservationDto',
        'water_level': 'WaterLevelDto',
        'weather_observation': 'WeatherObservationDto',
        'water_level2': 'WaterLevel2Dto',
        'damage_obs': 'list[DamageObsDto]',
        'density_profile': 'DensityProfileDto'
    }

    attribute_map = {
        'id': 'Id',
        'geo_hazard_tid': 'GeoHazardTID',
        'dt_obs_time': 'DtObsTime',
        'observer_guid': 'ObserverGuid',
        'email': 'Email',
        'obs_location_id': 'ObsLocationID',
        'observer_group_id': 'ObserverGroupID',
        'comment': 'Comment',
        'source_tid': 'SourceTID',
        'avalanche_activity_obs': 'AvalancheActivityObs',
        'avalanche_activity_obs2': 'AvalancheActivityObs2',
        'avalanche_danger_obs': 'AvalancheDangerObs',
        'avalanche_eval_problem2': 'AvalancheEvalProblem2',
        'avalanche_evaluation3': 'AvalancheEvaluation3',
        'avalanche_obs': 'AvalancheObs',
        'compression_test': 'CompressionTest',
        'danger_obs': 'DangerObs',
        'general_observation': 'GeneralObservation',
        'ice_cover_obs': 'IceCoverObs',
        'ice_thickness': 'IceThickness',
        'incident': 'Incident',
        'land_slide_obs': 'LandSlideObs',
        'obs_location': 'ObsLocation',
        'picture': 'Picture',
        'snow_cover_obs': 'SnowCoverObs',
        'snow_profile': 'SnowProfile',
        'snow_profile2': 'SnowProfile2',
        'snow_surface_observation': 'SnowSurfaceObservation',
        'water_level': 'WaterLevel',
        'weather_observation': 'WeatherObservation',
        'water_level2': 'WaterLevel2',
        'damage_obs': 'DamageObs',
        'density_profile': 'DensityProfile'
    }

    def __init__(self, id=None, geo_hazard_tid=None, dt_obs_time=None, observer_guid=None, email=None, obs_location_id=None, observer_group_id=None, comment=None, source_tid=None, avalanche_activity_obs=None, avalanche_activity_obs2=None, avalanche_danger_obs=None, avalanche_eval_problem2=None, avalanche_evaluation3=None, avalanche_obs=None, compression_test=None, danger_obs=None, general_observation=None, ice_cover_obs=None, ice_thickness=None, incident=None, land_slide_obs=None, obs_location=None, picture=None, snow_cover_obs=None, snow_profile=None, snow_profile2=None, snow_surface_observation=None, water_level=None, weather_observation=None, water_level2=None, damage_obs=None, density_profile=None):  # noqa: E501
        """CreateRegistrationRequestDto - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._geo_hazard_tid = None
        self._dt_obs_time = None
        self._observer_guid = None
        self._email = None
        self._obs_location_id = None
        self._observer_group_id = None
        self._comment = None
        self._source_tid = None
        self._avalanche_activity_obs = None
        self._avalanche_activity_obs2 = None
        self._avalanche_danger_obs = None
        self._avalanche_eval_problem2 = None
        self._avalanche_evaluation3 = None
        self._avalanche_obs = None
        self._compression_test = None
        self._danger_obs = None
        self._general_observation = None
        self._ice_cover_obs = None
        self._ice_thickness = None
        self._incident = None
        self._land_slide_obs = None
        self._obs_location = None
        self._picture = None
        self._snow_cover_obs = None
        self._snow_profile = None
        self._snow_profile2 = None
        self._snow_surface_observation = None
        self._water_level = None
        self._weather_observation = None
        self._water_level2 = None
        self._damage_obs = None
        self._density_profile = None
        self.discriminator = None
        self.id = id
        self.geo_hazard_tid = geo_hazard_tid
        self.dt_obs_time = dt_obs_time
        self.observer_guid = observer_guid
        if email is not None:
            self.email = email
        if obs_location_id is not None:
            self.obs_location_id = obs_location_id
        if observer_group_id is not None:
            self.observer_group_id = observer_group_id
        if comment is not None:
            self.comment = comment
        if source_tid is not None:
            self.source_tid = source_tid
        if avalanche_activity_obs is not None:
            self.avalanche_activity_obs = avalanche_activity_obs
        if avalanche_activity_obs2 is not None:
            self.avalanche_activity_obs2 = avalanche_activity_obs2
        if avalanche_danger_obs is not None:
            self.avalanche_danger_obs = avalanche_danger_obs
        if avalanche_eval_problem2 is not None:
            self.avalanche_eval_problem2 = avalanche_eval_problem2
        if avalanche_evaluation3 is not None:
            self.avalanche_evaluation3 = avalanche_evaluation3
        if avalanche_obs is not None:
            self.avalanche_obs = avalanche_obs
        if compression_test is not None:
            self.compression_test = compression_test
        if danger_obs is not None:
            self.danger_obs = danger_obs
        if general_observation is not None:
            self.general_observation = general_observation
        if ice_cover_obs is not None:
            self.ice_cover_obs = ice_cover_obs
        if ice_thickness is not None:
            self.ice_thickness = ice_thickness
        if incident is not None:
            self.incident = incident
        if land_slide_obs is not None:
            self.land_slide_obs = land_slide_obs
        if obs_location is not None:
            self.obs_location = obs_location
        if picture is not None:
            self.picture = picture
        if snow_cover_obs is not None:
            self.snow_cover_obs = snow_cover_obs
        if snow_profile is not None:
            self.snow_profile = snow_profile
        if snow_profile2 is not None:
            self.snow_profile2 = snow_profile2
        if snow_surface_observation is not None:
            self.snow_surface_observation = snow_surface_observation
        if water_level is not None:
            self.water_level = water_level
        if weather_observation is not None:
            self.weather_observation = weather_observation
        if water_level2 is not None:
            self.water_level2 = water_level2
        if damage_obs is not None:
            self.damage_obs = damage_obs
        if density_profile is not None:
            self.density_profile = density_profile

    @property
    def id(self):
        """Gets the id of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The id of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateRegistrationRequestDto.


        :param id: The id of this CreateRegistrationRequestDto.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this CreateRegistrationRequestDto.  # noqa: E501

        Sett naturfare. Tabellen brukes av alle naturfarer (snø, jord, vann, is). The GeoHazardKD unique identifier  # noqa: E501

        :return: The geo_hazard_tid of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this CreateRegistrationRequestDto.

        Sett naturfare. Tabellen brukes av alle naturfarer (snø, jord, vann, is). The GeoHazardKD unique identifier  # noqa: E501

        :param geo_hazard_tid: The geo_hazard_tid of this CreateRegistrationRequestDto.  # noqa: E501
        :type: int
        """
        if geo_hazard_tid is None:
            raise ValueError("Invalid value for `geo_hazard_tid`, must not be `None`")  # noqa: E501
        allowed_values = [0, 10, 20, 30, 40, 50, 60, 70, 100, 110, 200, 999]  # noqa: E501
        if geo_hazard_tid not in allowed_values:
            raise ValueError(
                "Invalid value for `geo_hazard_tid` ({0}), must be one of {1}"  # noqa: E501
                .format(geo_hazard_tid, allowed_values)
            )

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def dt_obs_time(self):
        """Gets the dt_obs_time of this CreateRegistrationRequestDto.  # noqa: E501

        Tiden da observasjonen ble gjort.  # noqa: E501

        :return: The dt_obs_time of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_obs_time

    @dt_obs_time.setter
    def dt_obs_time(self, dt_obs_time):
        """Sets the dt_obs_time of this CreateRegistrationRequestDto.

        Tiden da observasjonen ble gjort.  # noqa: E501

        :param dt_obs_time: The dt_obs_time of this CreateRegistrationRequestDto.  # noqa: E501
        :type: datetime
        """
        if dt_obs_time is None:
            raise ValueError("Invalid value for `dt_obs_time`, must not be `None`")  # noqa: E501

        self._dt_obs_time = dt_obs_time

    @property
    def observer_guid(self):
        """Gets the observer_guid of this CreateRegistrationRequestDto.  # noqa: E501

        Unik ID for observatører (brukere). Denne lages av regObs systemet.  # noqa: E501

        :return: The observer_guid of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._observer_guid

    @observer_guid.setter
    def observer_guid(self, observer_guid):
        """Sets the observer_guid of this CreateRegistrationRequestDto.

        Unik ID for observatører (brukere). Denne lages av regObs systemet.  # noqa: E501

        :param observer_guid: The observer_guid of this CreateRegistrationRequestDto.  # noqa: E501
        :type: str
        """
        if observer_guid is None:
            raise ValueError("Invalid value for `observer_guid`, must not be `None`")  # noqa: E501

        self._observer_guid = observer_guid

    @property
    def email(self):
        """Gets the email of this CreateRegistrationRequestDto.  # noqa: E501

        Wether or not a confirmation email should be sent to user for this registration.  # noqa: E501

        :return: The email of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: bool
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this CreateRegistrationRequestDto.

        Wether or not a confirmation email should be sent to user for this registration.  # noqa: E501

        :param email: The email of this CreateRegistrationRequestDto.  # noqa: E501
        :type: bool
        """

        self._email = email

    @property
    def obs_location_id(self):
        """Gets the obs_location_id of this CreateRegistrationRequestDto.  # noqa: E501

        Unik ID på ulike observasjonssteder.  # noqa: E501

        :return: The obs_location_id of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._obs_location_id

    @obs_location_id.setter
    def obs_location_id(self, obs_location_id):
        """Sets the obs_location_id of this CreateRegistrationRequestDto.

        Unik ID på ulike observasjonssteder.  # noqa: E501

        :param obs_location_id: The obs_location_id of this CreateRegistrationRequestDto.  # noqa: E501
        :type: int
        """

        self._obs_location_id = obs_location_id

    @property
    def observer_group_id(self):
        """Gets the observer_group_id of this CreateRegistrationRequestDto.  # noqa: E501

        Hvis en bruker registrerer en observasjon på vegne av en gruppe legges det til her.  # noqa: E501

        :return: The observer_group_id of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._observer_group_id

    @observer_group_id.setter
    def observer_group_id(self, observer_group_id):
        """Sets the observer_group_id of this CreateRegistrationRequestDto.

        Hvis en bruker registrerer en observasjon på vegne av en gruppe legges det til her.  # noqa: E501

        :param observer_group_id: The observer_group_id of this CreateRegistrationRequestDto.  # noqa: E501
        :type: int
        """

        self._observer_group_id = observer_group_id

    @property
    def comment(self):
        """Gets the comment of this CreateRegistrationRequestDto.  # noqa: E501

        Kommentarfelt brukt av systemet.  # noqa: E501

        :return: The comment of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CreateRegistrationRequestDto.

        Kommentarfelt brukt av systemet.  # noqa: E501

        :param comment: The comment of this CreateRegistrationRequestDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def source_tid(self):
        """Gets the source_tid of this CreateRegistrationRequestDto.  # noqa: E501

        Kildereferanse på en registrering. F.eks. har brukeren sette dette selv eller er det referert til fra nyheter. The SourceKD unique identifier  # noqa: E501

        :return: The source_tid of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._source_tid

    @source_tid.setter
    def source_tid(self, source_tid):
        """Sets the source_tid of this CreateRegistrationRequestDto.

        Kildereferanse på en registrering. F.eks. har brukeren sette dette selv eller er det referert til fra nyheter. The SourceKD unique identifier  # noqa: E501

        :param source_tid: The source_tid of this CreateRegistrationRequestDto.  # noqa: E501
        :type: int
        """

        self._source_tid = source_tid

    @property
    def avalanche_activity_obs(self):
        """Gets the avalanche_activity_obs of this CreateRegistrationRequestDto.  # noqa: E501

        Tabell for skredaktivitet.  # noqa: E501

        :return: The avalanche_activity_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[AvalancheActivityObsDto]
        """
        return self._avalanche_activity_obs

    @avalanche_activity_obs.setter
    def avalanche_activity_obs(self, avalanche_activity_obs):
        """Sets the avalanche_activity_obs of this CreateRegistrationRequestDto.

        Tabell for skredaktivitet.  # noqa: E501

        :param avalanche_activity_obs: The avalanche_activity_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[AvalancheActivityObsDto]
        """

        self._avalanche_activity_obs = avalanche_activity_obs

    @property
    def avalanche_activity_obs2(self):
        """Gets the avalanche_activity_obs2 of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The avalanche_activity_obs2 of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[AvalancheActivityObs2Dto]
        """
        return self._avalanche_activity_obs2

    @avalanche_activity_obs2.setter
    def avalanche_activity_obs2(self, avalanche_activity_obs2):
        """Sets the avalanche_activity_obs2 of this CreateRegistrationRequestDto.


        :param avalanche_activity_obs2: The avalanche_activity_obs2 of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[AvalancheActivityObs2Dto]
        """

        self._avalanche_activity_obs2 = avalanche_activity_obs2

    @property
    def avalanche_danger_obs(self):
        """Gets the avalanche_danger_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The avalanche_danger_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[AvalancheDangerObsDto]
        """
        return self._avalanche_danger_obs

    @avalanche_danger_obs.setter
    def avalanche_danger_obs(self, avalanche_danger_obs):
        """Sets the avalanche_danger_obs of this CreateRegistrationRequestDto.


        :param avalanche_danger_obs: The avalanche_danger_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[AvalancheDangerObsDto]
        """

        self._avalanche_danger_obs = avalanche_danger_obs

    @property
    def avalanche_eval_problem2(self):
        """Gets the avalanche_eval_problem2 of this CreateRegistrationRequestDto.  # noqa: E501

        Tabell for skredproblemet. Denne har vært under skredfarevurderingsskjema.  # noqa: E501

        :return: The avalanche_eval_problem2 of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[AvalancheEvalProblem2Dto]
        """
        return self._avalanche_eval_problem2

    @avalanche_eval_problem2.setter
    def avalanche_eval_problem2(self, avalanche_eval_problem2):
        """Sets the avalanche_eval_problem2 of this CreateRegistrationRequestDto.

        Tabell for skredproblemet. Denne har vært under skredfarevurderingsskjema.  # noqa: E501

        :param avalanche_eval_problem2: The avalanche_eval_problem2 of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[AvalancheEvalProblem2Dto]
        """

        self._avalanche_eval_problem2 = avalanche_eval_problem2

    @property
    def avalanche_evaluation3(self):
        """Gets the avalanche_evaluation3 of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The avalanche_evaluation3 of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: AvalancheEvaluation3Dto
        """
        return self._avalanche_evaluation3

    @avalanche_evaluation3.setter
    def avalanche_evaluation3(self, avalanche_evaluation3):
        """Sets the avalanche_evaluation3 of this CreateRegistrationRequestDto.


        :param avalanche_evaluation3: The avalanche_evaluation3 of this CreateRegistrationRequestDto.  # noqa: E501
        :type: AvalancheEvaluation3Dto
        """

        self._avalanche_evaluation3 = avalanche_evaluation3

    @property
    def avalanche_obs(self):
        """Gets the avalanche_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The avalanche_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: AvalancheObsDto
        """
        return self._avalanche_obs

    @avalanche_obs.setter
    def avalanche_obs(self, avalanche_obs):
        """Sets the avalanche_obs of this CreateRegistrationRequestDto.


        :param avalanche_obs: The avalanche_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: AvalancheObsDto
        """

        self._avalanche_obs = avalanche_obs

    @property
    def compression_test(self):
        """Gets the compression_test of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The compression_test of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[CompressionTestDto]
        """
        return self._compression_test

    @compression_test.setter
    def compression_test(self, compression_test):
        """Sets the compression_test of this CreateRegistrationRequestDto.


        :param compression_test: The compression_test of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[CompressionTestDto]
        """

        self._compression_test = compression_test

    @property
    def danger_obs(self):
        """Gets the danger_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The danger_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[DangerObsDto]
        """
        return self._danger_obs

    @danger_obs.setter
    def danger_obs(self, danger_obs):
        """Sets the danger_obs of this CreateRegistrationRequestDto.


        :param danger_obs: The danger_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[DangerObsDto]
        """

        self._danger_obs = danger_obs

    @property
    def general_observation(self):
        """Gets the general_observation of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The general_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: GeneralObservationEditModel
        """
        return self._general_observation

    @general_observation.setter
    def general_observation(self, general_observation):
        """Sets the general_observation of this CreateRegistrationRequestDto.


        :param general_observation: The general_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :type: GeneralObservationEditModel
        """

        self._general_observation = general_observation

    @property
    def ice_cover_obs(self):
        """Gets the ice_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The ice_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: IceCoverObsDto
        """
        return self._ice_cover_obs

    @ice_cover_obs.setter
    def ice_cover_obs(self, ice_cover_obs):
        """Sets the ice_cover_obs of this CreateRegistrationRequestDto.


        :param ice_cover_obs: The ice_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: IceCoverObsDto
        """

        self._ice_cover_obs = ice_cover_obs

    @property
    def ice_thickness(self):
        """Gets the ice_thickness of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The ice_thickness of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: IceThicknessDto
        """
        return self._ice_thickness

    @ice_thickness.setter
    def ice_thickness(self, ice_thickness):
        """Sets the ice_thickness of this CreateRegistrationRequestDto.


        :param ice_thickness: The ice_thickness of this CreateRegistrationRequestDto.  # noqa: E501
        :type: IceThicknessDto
        """

        self._ice_thickness = ice_thickness

    @property
    def incident(self):
        """Gets the incident of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The incident of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: IncidentDto
        """
        return self._incident

    @incident.setter
    def incident(self, incident):
        """Sets the incident of this CreateRegistrationRequestDto.


        :param incident: The incident of this CreateRegistrationRequestDto.  # noqa: E501
        :type: IncidentDto
        """

        self._incident = incident

    @property
    def land_slide_obs(self):
        """Gets the land_slide_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The land_slide_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: LandSlideObsDto
        """
        return self._land_slide_obs

    @land_slide_obs.setter
    def land_slide_obs(self, land_slide_obs):
        """Sets the land_slide_obs of this CreateRegistrationRequestDto.


        :param land_slide_obs: The land_slide_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: LandSlideObsDto
        """

        self._land_slide_obs = land_slide_obs

    @property
    def obs_location(self):
        """Gets the obs_location of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The obs_location of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: ObsLocationDto
        """
        return self._obs_location

    @obs_location.setter
    def obs_location(self, obs_location):
        """Sets the obs_location of this CreateRegistrationRequestDto.


        :param obs_location: The obs_location of this CreateRegistrationRequestDto.  # noqa: E501
        :type: ObsLocationDto
        """

        self._obs_location = obs_location

    @property
    def picture(self):
        """Gets the picture of this CreateRegistrationRequestDto.  # noqa: E501

        Tabell for bilder.  # noqa: E501

        :return: The picture of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[PictureRequestDto]
        """
        return self._picture

    @picture.setter
    def picture(self, picture):
        """Sets the picture of this CreateRegistrationRequestDto.

        Tabell for bilder.  # noqa: E501

        :param picture: The picture of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[PictureRequestDto]
        """

        self._picture = picture

    @property
    def snow_cover_obs(self):
        """Gets the snow_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The snow_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: SnowCoverObsDto
        """
        return self._snow_cover_obs

    @snow_cover_obs.setter
    def snow_cover_obs(self, snow_cover_obs):
        """Sets the snow_cover_obs of this CreateRegistrationRequestDto.


        :param snow_cover_obs: The snow_cover_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: SnowCoverObsDto
        """

        self._snow_cover_obs = snow_cover_obs

    @property
    def snow_profile(self):
        """Gets the snow_profile of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The snow_profile of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: PictureRequestDto
        """
        return self._snow_profile

    @snow_profile.setter
    def snow_profile(self, snow_profile):
        """Sets the snow_profile of this CreateRegistrationRequestDto.


        :param snow_profile: The snow_profile of this CreateRegistrationRequestDto.  # noqa: E501
        :type: PictureRequestDto
        """

        self._snow_profile = snow_profile

    @property
    def snow_profile2(self):
        """Gets the snow_profile2 of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The snow_profile2 of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: SnowProfileDto
        """
        return self._snow_profile2

    @snow_profile2.setter
    def snow_profile2(self, snow_profile2):
        """Sets the snow_profile2 of this CreateRegistrationRequestDto.


        :param snow_profile2: The snow_profile2 of this CreateRegistrationRequestDto.  # noqa: E501
        :type: SnowProfileDto
        """

        self._snow_profile2 = snow_profile2

    @property
    def snow_surface_observation(self):
        """Gets the snow_surface_observation of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The snow_surface_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: SnowSurfaceObservationDto
        """
        return self._snow_surface_observation

    @snow_surface_observation.setter
    def snow_surface_observation(self, snow_surface_observation):
        """Sets the snow_surface_observation of this CreateRegistrationRequestDto.


        :param snow_surface_observation: The snow_surface_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :type: SnowSurfaceObservationDto
        """

        self._snow_surface_observation = snow_surface_observation

    @property
    def water_level(self):
        """Gets the water_level of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The water_level of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: WaterLevelDto
        """
        return self._water_level

    @water_level.setter
    def water_level(self, water_level):
        """Sets the water_level of this CreateRegistrationRequestDto.


        :param water_level: The water_level of this CreateRegistrationRequestDto.  # noqa: E501
        :type: WaterLevelDto
        """

        self._water_level = water_level

    @property
    def weather_observation(self):
        """Gets the weather_observation of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The weather_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: WeatherObservationDto
        """
        return self._weather_observation

    @weather_observation.setter
    def weather_observation(self, weather_observation):
        """Sets the weather_observation of this CreateRegistrationRequestDto.


        :param weather_observation: The weather_observation of this CreateRegistrationRequestDto.  # noqa: E501
        :type: WeatherObservationDto
        """

        self._weather_observation = weather_observation

    @property
    def water_level2(self):
        """Gets the water_level2 of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The water_level2 of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: WaterLevel2Dto
        """
        return self._water_level2

    @water_level2.setter
    def water_level2(self, water_level2):
        """Sets the water_level2 of this CreateRegistrationRequestDto.


        :param water_level2: The water_level2 of this CreateRegistrationRequestDto.  # noqa: E501
        :type: WaterLevel2Dto
        """

        self._water_level2 = water_level2

    @property
    def damage_obs(self):
        """Gets the damage_obs of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The damage_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: list[DamageObsDto]
        """
        return self._damage_obs

    @damage_obs.setter
    def damage_obs(self, damage_obs):
        """Sets the damage_obs of this CreateRegistrationRequestDto.


        :param damage_obs: The damage_obs of this CreateRegistrationRequestDto.  # noqa: E501
        :type: list[DamageObsDto]
        """

        self._damage_obs = damage_obs

    @property
    def density_profile(self):
        """Gets the density_profile of this CreateRegistrationRequestDto.  # noqa: E501


        :return: The density_profile of this CreateRegistrationRequestDto.  # noqa: E501
        :rtype: DensityProfileDto
        """
        return self._density_profile

    @density_profile.setter
    def density_profile(self, density_profile):
        """Sets the density_profile of this CreateRegistrationRequestDto.


        :param density_profile: The density_profile of this CreateRegistrationRequestDto.  # noqa: E501
        :type: DensityProfileDto
        """

        self._density_profile = density_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateRegistrationRequestDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateRegistrationRequestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ForecastRegionSubRegionDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'text': 'str',
        'region_type': 'str',
        'sort_order': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'text': 'Text',
        'region_type': 'RegionType',
        'sort_order': 'SortOrder'
    }

    def __init__(self, id=None, text=None, region_type=None, sort_order=None):  # noqa: E501
        """ForecastRegionSubRegionDto - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._text = None
        self._region_type = None
        self._sort_order = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if text is not None:
            self.text = text
        if region_type is not None:
            self.region_type = region_type
        if sort_order is not None:
            self.sort_order = sort_order

    @property
    def id(self):
        """Gets the id of this ForecastRegionSubRegionDto.  # noqa: E501


        :return: The id of this ForecastRegionSubRegionDto.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ForecastRegionSubRegionDto.


        :param id: The id of this ForecastRegionSubRegionDto.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def text(self):
        """Gets the text of this ForecastRegionSubRegionDto.  # noqa: E501


        :return: The text of this ForecastRegionSubRegionDto.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this ForecastRegionSubRegionDto.


        :param text: The text of this ForecastRegionSubRegionDto.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def region_type(self):
        """Gets the region_type of this ForecastRegionSubRegionDto.  # noqa: E501


        :return: The region_type of this ForecastRegionSubRegionDto.  # noqa: E501
        :rtype: str
        """
        return self._region_type

    @region_type.setter
    def region_type(self, region_type):
        """Sets the region_type of this ForecastRegionSubRegionDto.


        :param region_type: The region_type of this ForecastRegionSubRegionDto.  # noqa: E501
        :type: str
        """

        self._region_type = region_type

    @property
    def sort_order(self):
        """Gets the sort_order of this ForecastRegionSubRegionDto.  # noqa: E501


        :return: The sort_order of this ForecastRegionSubRegionDto.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this ForecastRegionSubRegionDto.


        :param sort_order: The sort_order of this ForecastRegionSubRegionDto.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ForecastRegionSubRegionDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ForecastRegionSubRegionDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SnowCoverObsDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'depth_hoar_thickness': 'float',
        'critical_layer_exists': 'bool',
        'critical_layer_location': 'float',
        'critical_layer_tid': 'int',
        'snow_pilot_ref': 'str',
        'usage_flag_tid': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'depth_hoar_thickness': 'DepthHoarThickness',
        'critical_layer_exists': 'CriticalLayerExists',
        'critical_layer_location': 'CriticalLayerLocation',
        'critical_layer_tid': 'CriticalLayerTID',
        'snow_pilot_ref': 'SnowPilotRef',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment'
    }

    def __init__(self, depth_hoar_thickness=None, critical_layer_exists=None, critical_layer_location=None, critical_layer_tid=None, snow_pilot_ref=None, usage_flag_tid=None, comment=None):  # noqa: E501
        """SnowCoverObsDto - a model defined in Swagger"""  # noqa: E501
        self._depth_hoar_thickness = None
        self._critical_layer_exists = None
        self._critical_layer_location = None
        self._critical_layer_tid = None
        self._snow_pilot_ref = None
        self._usage_flag_tid = None
        self._comment = None
        self.discriminator = None
        if depth_hoar_thickness is not None:
            self.depth_hoar_thickness = depth_hoar_thickness
        if critical_layer_exists is not None:
            self.critical_layer_exists = critical_layer_exists
        if critical_layer_location is not None:
            self.critical_layer_location = critical_layer_location
        if critical_layer_tid is not None:
            self.critical_layer_tid = critical_layer_tid
        if snow_pilot_ref is not None:
            self.snow_pilot_ref = snow_pilot_ref
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment

    @property
    def depth_hoar_thickness(self):
        """Gets the depth_hoar_thickness of this SnowCoverObsDto.  # noqa: E501

        DepthHoarThickness  # noqa: E501

        :return: The depth_hoar_thickness of this SnowCoverObsDto.  # noqa: E501
        :rtype: float
        """
        return self._depth_hoar_thickness

    @depth_hoar_thickness.setter
    def depth_hoar_thickness(self, depth_hoar_thickness):
        """Sets the depth_hoar_thickness of this SnowCoverObsDto.

        DepthHoarThickness  # noqa: E501

        :param depth_hoar_thickness: The depth_hoar_thickness of this SnowCoverObsDto.  # noqa: E501
        :type: float
        """

        self._depth_hoar_thickness = depth_hoar_thickness

    @property
    def critical_layer_exists(self):
        """Gets the critical_layer_exists of this SnowCoverObsDto.  # noqa: E501

        CriticalLayerExists  # noqa: E501

        :return: The critical_layer_exists of this SnowCoverObsDto.  # noqa: E501
        :rtype: bool
        """
        return self._critical_layer_exists

    @critical_layer_exists.setter
    def critical_layer_exists(self, critical_layer_exists):
        """Sets the critical_layer_exists of this SnowCoverObsDto.

        CriticalLayerExists  # noqa: E501

        :param critical_layer_exists: The critical_layer_exists of this SnowCoverObsDto.  # noqa: E501
        :type: bool
        """

        self._critical_layer_exists = critical_layer_exists

    @property
    def critical_layer_location(self):
        """Gets the critical_layer_location of this SnowCoverObsDto.  # noqa: E501

        CriticalLayerLocation  # noqa: E501

        :return: The critical_layer_location of this SnowCoverObsDto.  # noqa: E501
        :rtype: float
        """
        return self._critical_layer_location

    @critical_layer_location.setter
    def critical_layer_location(self, critical_layer_location):
        """Sets the critical_layer_location of this SnowCoverObsDto.

        CriticalLayerLocation  # noqa: E501

        :param critical_layer_location: The critical_layer_location of this SnowCoverObsDto.  # noqa: E501
        :type: float
        """

        self._critical_layer_location = critical_layer_location

    @property
    def critical_layer_tid(self):
        """Gets the critical_layer_tid of this SnowCoverObsDto.  # noqa: E501

        The CriticalLayerKD unique identifier  # noqa: E501

        :return: The critical_layer_tid of this SnowCoverObsDto.  # noqa: E501
        :rtype: int
        """
        return self._critical_layer_tid

    @critical_layer_tid.setter
    def critical_layer_tid(self, critical_layer_tid):
        """Sets the critical_layer_tid of this SnowCoverObsDto.

        The CriticalLayerKD unique identifier  # noqa: E501

        :param critical_layer_tid: The critical_layer_tid of this SnowCoverObsDto.  # noqa: E501
        :type: int
        """

        self._critical_layer_tid = critical_layer_tid

    @property
    def snow_pilot_ref(self):
        """Gets the snow_pilot_ref of this SnowCoverObsDto.  # noqa: E501

        SnowPilotRef  # noqa: E501

        :return: The snow_pilot_ref of this SnowCoverObsDto.  # noqa: E501
        :rtype: str
        """
        return self._snow_pilot_ref

    @snow_pilot_ref.setter
    def snow_pilot_ref(self, snow_pilot_ref):
        """Sets the snow_pilot_ref of this SnowCoverObsDto.

        SnowPilotRef  # noqa: E501

        :param snow_pilot_ref: The snow_pilot_ref of this SnowCoverObsDto.  # noqa: E501
        :type: str
        """

        self._snow_pilot_ref = snow_pilot_ref

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this SnowCoverObsDto.  # noqa: E501

        UsageFlagTID  # noqa: E501

        :return: The usage_flag_tid of this SnowCoverObsDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this SnowCoverObsDto.

        UsageFlagTID  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this SnowCoverObsDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this SnowCoverObsDto.  # noqa: E501

        Comment.  # noqa: E501

        :return: The comment of this SnowCoverObsDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SnowCoverObsDto.

        Comment.  # noqa: E501

        :param comment: The comment of this SnowCoverObsDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnowCoverObsDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnowCoverObsDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class ObsLocationDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latitude': 'float',
        'longitude': 'float',
        'obs_location_id': 'int',
        'location_name': 'str',
        'utm_zone': 'int',
        'utm_east': 'int',
        'utm_north': 'int',
        'utm_source_tid': 'int',
        'forecast_region_tid': 'int',
        'municipal_no': 'str',
        'location_description': 'str',
        'comment': 'str',
        'uncertainty': 'int'
    }

    attribute_map = {
        'latitude': 'Latitude',
        'longitude': 'Longitude',
        'obs_location_id': 'ObsLocationID',
        'location_name': 'LocationName',
        'utm_zone': 'UTMZone',
        'utm_east': 'UTMEast',
        'utm_north': 'UTMNorth',
        'utm_source_tid': 'UTMSourceTID',
        'forecast_region_tid': 'ForecastRegionTID',
        'municipal_no': 'MunicipalNo',
        'location_description': 'LocationDescription',
        'comment': 'Comment',
        'uncertainty': 'Uncertainty'
    }

    def __init__(self, latitude=None, longitude=None, obs_location_id=None, location_name=None, utm_zone=None, utm_east=None, utm_north=None, utm_source_tid=None, forecast_region_tid=None, municipal_no=None, location_description=None, comment=None, uncertainty=None):  # noqa: E501
        """ObsLocationDto - a model defined in Swagger"""  # noqa: E501
        self._latitude = None
        self._longitude = None
        self._obs_location_id = None
        self._location_name = None
        self._utm_zone = None
        self._utm_east = None
        self._utm_north = None
        self._utm_source_tid = None
        self._forecast_region_tid = None
        self._municipal_no = None
        self._location_description = None
        self._comment = None
        self._uncertainty = None
        self.discriminator = None
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
        if obs_location_id is not None:
            self.obs_location_id = obs_location_id
        if location_name is not None:
            self.location_name = location_name
        if utm_zone is not None:
            self.utm_zone = utm_zone
        if utm_east is not None:
            self.utm_east = utm_east
        if utm_north is not None:
            self.utm_north = utm_north
        if utm_source_tid is not None:
            self.utm_source_tid = utm_source_tid
        if forecast_region_tid is not None:
            self.forecast_region_tid = forecast_region_tid
        if municipal_no is not None:
            self.municipal_no = municipal_no
        if location_description is not None:
            self.location_description = location_description
        if comment is not None:
            self.comment = comment
        if uncertainty is not None:
            self.uncertainty = uncertainty

    @property
    def latitude(self):
        """Gets the latitude of this ObsLocationDto.  # noqa: E501

        Latitude  # noqa: E501

        :return: The latitude of this ObsLocationDto.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this ObsLocationDto.

        Latitude  # noqa: E501

        :param latitude: The latitude of this ObsLocationDto.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def longitude(self):
        """Gets the longitude of this ObsLocationDto.  # noqa: E501

        Longitude  # noqa: E501

        :return: The longitude of this ObsLocationDto.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this ObsLocationDto.

        Longitude  # noqa: E501

        :param longitude: The longitude of this ObsLocationDto.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def obs_location_id(self):
        """Gets the obs_location_id of this ObsLocationDto.  # noqa: E501

        ObsLocationID  # noqa: E501

        :return: The obs_location_id of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._obs_location_id

    @obs_location_id.setter
    def obs_location_id(self, obs_location_id):
        """Sets the obs_location_id of this ObsLocationDto.

        ObsLocationID  # noqa: E501

        :param obs_location_id: The obs_location_id of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._obs_location_id = obs_location_id

    @property
    def location_name(self):
        """Gets the location_name of this ObsLocationDto.  # noqa: E501

        Navn på stedet  # noqa: E501

        :return: The location_name of this ObsLocationDto.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this ObsLocationDto.

        Navn på stedet  # noqa: E501

        :param location_name: The location_name of this ObsLocationDto.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def utm_zone(self):
        """Gets the utm_zone of this ObsLocationDto.  # noqa: E501

        UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34  # noqa: E501

        :return: The utm_zone of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone

    @utm_zone.setter
    def utm_zone(self, utm_zone):
        """Sets the utm_zone of this ObsLocationDto.

        UTM sone. Merk at kartene i norge ligger mellom UTM32 og 34  # noqa: E501

        :param utm_zone: The utm_zone of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._utm_zone = utm_zone

    @property
    def utm_east(self):
        """Gets the utm_east of this ObsLocationDto.  # noqa: E501

        Østlig UTM sone uten desimaler  # noqa: E501

        :return: The utm_east of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_east

    @utm_east.setter
    def utm_east(self, utm_east):
        """Sets the utm_east of this ObsLocationDto.

        Østlig UTM sone uten desimaler  # noqa: E501

        :param utm_east: The utm_east of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._utm_east = utm_east

    @property
    def utm_north(self):
        """Gets the utm_north of this ObsLocationDto.  # noqa: E501

        Nordlig UTM sone uten desimaler  # noqa: E501

        :return: The utm_north of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_north

    @utm_north.setter
    def utm_north(self, utm_north):
        """Sets the utm_north of this ObsLocationDto.

        Nordlig UTM sone uten desimaler  # noqa: E501

        :param utm_north: The utm_north of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._utm_north = utm_north

    @property
    def utm_source_tid(self):
        """Gets the utm_source_tid of this ObsLocationDto.  # noqa: E501

        Kildehenvisning på hvordan koordinaten er satt. (GPS i tlf, klikk i kart, osv). Verdier gitt i UTMSourceKD  # noqa: E501

        :return: The utm_source_tid of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_source_tid

    @utm_source_tid.setter
    def utm_source_tid(self, utm_source_tid):
        """Sets the utm_source_tid of this ObsLocationDto.

        Kildehenvisning på hvordan koordinaten er satt. (GPS i tlf, klikk i kart, osv). Verdier gitt i UTMSourceKD  # noqa: E501

        :param utm_source_tid: The utm_source_tid of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._utm_source_tid = utm_source_tid

    @property
    def forecast_region_tid(self):
        """Gets the forecast_region_tid of this ObsLocationDto.  # noqa: E501

        Anngir varslingsregion stedet tilhører. Varslingsregioner gitt i ForecastRegionKD. The ForecastRegionKD unique identifier  # noqa: E501

        :return: The forecast_region_tid of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._forecast_region_tid

    @forecast_region_tid.setter
    def forecast_region_tid(self, forecast_region_tid):
        """Sets the forecast_region_tid of this ObsLocationDto.

        Anngir varslingsregion stedet tilhører. Varslingsregioner gitt i ForecastRegionKD. The ForecastRegionKD unique identifier  # noqa: E501

        :param forecast_region_tid: The forecast_region_tid of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._forecast_region_tid = forecast_region_tid

    @property
    def municipal_no(self):
        """Gets the municipal_no of this ObsLocationDto.  # noqa: E501

        Kommune nr stedet tilhører  # noqa: E501

        :return: The municipal_no of this ObsLocationDto.  # noqa: E501
        :rtype: str
        """
        return self._municipal_no

    @municipal_no.setter
    def municipal_no(self, municipal_no):
        """Sets the municipal_no of this ObsLocationDto.

        Kommune nr stedet tilhører  # noqa: E501

        :param municipal_no: The municipal_no of this ObsLocationDto.  # noqa: E501
        :type: str
        """

        self._municipal_no = municipal_no

    @property
    def location_description(self):
        """Gets the location_description of this ObsLocationDto.  # noqa: E501

        Beskriver stedet.  # noqa: E501

        :return: The location_description of this ObsLocationDto.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this ObsLocationDto.

        Beskriver stedet.  # noqa: E501

        :param location_description: The location_description of this ObsLocationDto.  # noqa: E501
        :type: str
        """

        self._location_description = location_description

    @property
    def comment(self):
        """Gets the comment of this ObsLocationDto.  # noqa: E501

        Kommentarfelt brukt av systemet. Altså vises ikke til brukerne.  # noqa: E501

        :return: The comment of this ObsLocationDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this ObsLocationDto.

        Kommentarfelt brukt av systemet. Altså vises ikke til brukerne.  # noqa: E501

        :param comment: The comment of this ObsLocationDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def uncertainty(self):
        """Gets the uncertainty of this ObsLocationDto.  # noqa: E501

        Usikkerhet i posisjon i meter. Anslås på web og i app hentes det fra gps.  # noqa: E501

        :return: The uncertainty of this ObsLocationDto.  # noqa: E501
        :rtype: int
        """
        return self._uncertainty

    @uncertainty.setter
    def uncertainty(self, uncertainty):
        """Sets the uncertainty of this ObsLocationDto.

        Usikkerhet i posisjon i meter. Anslås på web og i app hentes det fra gps.  # noqa: E501

        :param uncertainty: The uncertainty of this ObsLocationDto.  # noqa: E501
        :type: int
        """

        self._uncertainty = uncertainty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ObsLocationDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObsLocationDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class StratProfileLayerDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'sort_order': 'int',
        'thickness': 'float',
        'hardness_tid': 'int',
        'grain_form_primary_tid': 'int',
        'grain_form_secondary_tid': 'int',
        'grain_size_avg': 'float',
        'grain_size_avg_max': 'float',
        'hardness_bottom_tid': 'int',
        'wetness_tid': 'int',
        'critical_layer_tid': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'sort_order': 'SortOrder',
        'thickness': 'Thickness',
        'hardness_tid': 'HardnessTID',
        'grain_form_primary_tid': 'GrainFormPrimaryTID',
        'grain_form_secondary_tid': 'GrainFormSecondaryTID',
        'grain_size_avg': 'GrainSizeAvg',
        'grain_size_avg_max': 'GrainSizeAvgMax',
        'hardness_bottom_tid': 'HardnessBottomTID',
        'wetness_tid': 'WetnessTID',
        'critical_layer_tid': 'CriticalLayerTID',
        'comment': 'Comment'
    }

    def __init__(self, sort_order=None, thickness=None, hardness_tid=None, grain_form_primary_tid=None, grain_form_secondary_tid=None, grain_size_avg=None, grain_size_avg_max=None, hardness_bottom_tid=None, wetness_tid=None, critical_layer_tid=None, comment=None):  # noqa: E501
        """StratProfileLayerDto - a model defined in Swagger"""  # noqa: E501
        self._sort_order = None
        self._thickness = None
        self._hardness_tid = None
        self._grain_form_primary_tid = None
        self._grain_form_secondary_tid = None
        self._grain_size_avg = None
        self._grain_size_avg_max = None
        self._hardness_bottom_tid = None
        self._wetness_tid = None
        self._critical_layer_tid = None
        self._comment = None
        self.discriminator = None
        if sort_order is not None:
            self.sort_order = sort_order
        if thickness is not None:
            self.thickness = thickness
        if hardness_tid is not None:
            self.hardness_tid = hardness_tid
        if grain_form_primary_tid is not None:
            self.grain_form_primary_tid = grain_form_primary_tid
        if grain_form_secondary_tid is not None:
            self.grain_form_secondary_tid = grain_form_secondary_tid
        if grain_size_avg is not None:
            self.grain_size_avg = grain_size_avg
        if grain_size_avg_max is not None:
            self.grain_size_avg_max = grain_size_avg_max
        if hardness_bottom_tid is not None:
            self.hardness_bottom_tid = hardness_bottom_tid
        if wetness_tid is not None:
            self.wetness_tid = wetness_tid
        if critical_layer_tid is not None:
            self.critical_layer_tid = critical_layer_tid
        if comment is not None:
            self.comment = comment

    @property
    def sort_order(self):
        """Gets the sort_order of this StratProfileLayerDto.  # noqa: E501


        :return: The sort_order of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this StratProfileLayerDto.


        :param sort_order: The sort_order of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def thickness(self):
        """Gets the thickness of this StratProfileLayerDto.  # noqa: E501


        :return: The thickness of this StratProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._thickness

    @thickness.setter
    def thickness(self, thickness):
        """Sets the thickness of this StratProfileLayerDto.


        :param thickness: The thickness of this StratProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._thickness = thickness

    @property
    def hardness_tid(self):
        """Gets the hardness_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The hardness_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._hardness_tid

    @hardness_tid.setter
    def hardness_tid(self, hardness_tid):
        """Sets the hardness_tid of this StratProfileLayerDto.


        :param hardness_tid: The hardness_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._hardness_tid = hardness_tid

    @property
    def grain_form_primary_tid(self):
        """Gets the grain_form_primary_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The grain_form_primary_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._grain_form_primary_tid

    @grain_form_primary_tid.setter
    def grain_form_primary_tid(self, grain_form_primary_tid):
        """Sets the grain_form_primary_tid of this StratProfileLayerDto.


        :param grain_form_primary_tid: The grain_form_primary_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._grain_form_primary_tid = grain_form_primary_tid

    @property
    def grain_form_secondary_tid(self):
        """Gets the grain_form_secondary_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The grain_form_secondary_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._grain_form_secondary_tid

    @grain_form_secondary_tid.setter
    def grain_form_secondary_tid(self, grain_form_secondary_tid):
        """Sets the grain_form_secondary_tid of this StratProfileLayerDto.


        :param grain_form_secondary_tid: The grain_form_secondary_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._grain_form_secondary_tid = grain_form_secondary_tid

    @property
    def grain_size_avg(self):
        """Gets the grain_size_avg of this StratProfileLayerDto.  # noqa: E501


        :return: The grain_size_avg of this StratProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._grain_size_avg

    @grain_size_avg.setter
    def grain_size_avg(self, grain_size_avg):
        """Sets the grain_size_avg of this StratProfileLayerDto.


        :param grain_size_avg: The grain_size_avg of this StratProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._grain_size_avg = grain_size_avg

    @property
    def grain_size_avg_max(self):
        """Gets the grain_size_avg_max of this StratProfileLayerDto.  # noqa: E501


        :return: The grain_size_avg_max of this StratProfileLayerDto.  # noqa: E501
        :rtype: float
        """
        return self._grain_size_avg_max

    @grain_size_avg_max.setter
    def grain_size_avg_max(self, grain_size_avg_max):
        """Sets the grain_size_avg_max of this StratProfileLayerDto.


        :param grain_size_avg_max: The grain_size_avg_max of this StratProfileLayerDto.  # noqa: E501
        :type: float
        """

        self._grain_size_avg_max = grain_size_avg_max

    @property
    def hardness_bottom_tid(self):
        """Gets the hardness_bottom_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The hardness_bottom_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._hardness_bottom_tid

    @hardness_bottom_tid.setter
    def hardness_bottom_tid(self, hardness_bottom_tid):
        """Sets the hardness_bottom_tid of this StratProfileLayerDto.


        :param hardness_bottom_tid: The hardness_bottom_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._hardness_bottom_tid = hardness_bottom_tid

    @property
    def wetness_tid(self):
        """Gets the wetness_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The wetness_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._wetness_tid

    @wetness_tid.setter
    def wetness_tid(self, wetness_tid):
        """Sets the wetness_tid of this StratProfileLayerDto.


        :param wetness_tid: The wetness_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._wetness_tid = wetness_tid

    @property
    def critical_layer_tid(self):
        """Gets the critical_layer_tid of this StratProfileLayerDto.  # noqa: E501


        :return: The critical_layer_tid of this StratProfileLayerDto.  # noqa: E501
        :rtype: int
        """
        return self._critical_layer_tid

    @critical_layer_tid.setter
    def critical_layer_tid(self, critical_layer_tid):
        """Sets the critical_layer_tid of this StratProfileLayerDto.


        :param critical_layer_tid: The critical_layer_tid of this StratProfileLayerDto.  # noqa: E501
        :type: int
        """

        self._critical_layer_tid = critical_layer_tid

    @property
    def comment(self):
        """Gets the comment of this StratProfileLayerDto.  # noqa: E501


        :return: The comment of this StratProfileLayerDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this StratProfileLayerDto.


        :param comment: The comment of this StratProfileLayerDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StratProfileLayerDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StratProfileLayerDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheObsDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dt_avalanche_time': 'datetime',
        'aspect': 'int',
        'height_start_zone': 'int',
        'height_stop_zone': 'int',
        'destructive_size_tid': 'int',
        'avalanche_trigger_tid': 'int',
        'avalanche_tid': 'int',
        'terrain_start_zone_tid': 'int',
        'utm_zone_stop': 'int',
        'utm_east_stop': 'int',
        'utm_north_stop': 'int',
        'utm_east_start': 'int',
        'snow_line': 'int',
        'valid_exposition': 'str',
        'aval_cause_tid': 'int',
        'fracture_height': 'int',
        'fracture_width': 'int',
        'trajectory': 'str',
        'start_lat': 'float',
        'start_long': 'float',
        'stop_lat': 'float',
        'stop_long': 'float',
        'usage_flag_tid': 'int',
        'comment': 'str',
        'utm_north_start': 'int'
    }

    attribute_map = {
        'dt_avalanche_time': 'DtAvalancheTime',
        'aspect': 'Aspect',
        'height_start_zone': 'HeightStartZone',
        'height_stop_zone': 'HeightStopZone',
        'destructive_size_tid': 'DestructiveSizeTID',
        'avalanche_trigger_tid': 'AvalancheTriggerTID',
        'avalanche_tid': 'AvalancheTID',
        'terrain_start_zone_tid': 'TerrainStartZoneTID',
        'utm_zone_stop': 'UTMZoneStop',
        'utm_east_stop': 'UTMEastStop',
        'utm_north_stop': 'UTMNorthStop',
        'utm_east_start': 'UTMEastStart',
        'snow_line': 'SnowLine',
        'valid_exposition': 'ValidExposition',
        'aval_cause_tid': 'AvalCauseTID',
        'fracture_height': 'FractureHeight',
        'fracture_width': 'FractureWidth',
        'trajectory': 'Trajectory',
        'start_lat': 'StartLat',
        'start_long': 'StartLong',
        'stop_lat': 'StopLat',
        'stop_long': 'StopLong',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment',
        'utm_north_start': 'UTMNorthStart'
    }

    def __init__(self, dt_avalanche_time=None, aspect=None, height_start_zone=None, height_stop_zone=None, destructive_size_tid=None, avalanche_trigger_tid=None, avalanche_tid=None, terrain_start_zone_tid=None, utm_zone_stop=None, utm_east_stop=None, utm_north_stop=None, utm_east_start=None, snow_line=None, valid_exposition=None, aval_cause_tid=None, fracture_height=None, fracture_width=None, trajectory=None, start_lat=None, start_long=None, stop_lat=None, stop_long=None, usage_flag_tid=None, comment=None, utm_north_start=None):  # noqa: E501
        """AvalancheObsDto - a model defined in Swagger"""  # noqa: E501
        self._dt_avalanche_time = None
        self._aspect = None
        self._height_start_zone = None
        self._height_stop_zone = None
        self._destructive_size_tid = None
        self._avalanche_trigger_tid = None
        self._avalanche_tid = None
        self._terrain_start_zone_tid = None
        self._utm_zone_stop = None
        self._utm_east_stop = None
        self._utm_north_stop = None
        self._utm_east_start = None
        self._snow_line = None
        self._valid_exposition = None
        self._aval_cause_tid = None
        self._fracture_height = None
        self._fracture_width = None
        self._trajectory = None
        self._start_lat = None
        self._start_long = None
        self._stop_lat = None
        self._stop_long = None
        self._usage_flag_tid = None
        self._comment = None
        self._utm_north_start = None
        self.discriminator = None
        self.dt_avalanche_time = dt_avalanche_time
        if aspect is not None:
            self.aspect = aspect
        if height_start_zone is not None:
            self.height_start_zone = height_start_zone
        if height_stop_zone is not None:
            self.height_stop_zone = height_stop_zone
        if destructive_size_tid is not None:
            self.destructive_size_tid = destructive_size_tid
        if avalanche_trigger_tid is not None:
            self.avalanche_trigger_tid = avalanche_trigger_tid
        if avalanche_tid is not None:
            self.avalanche_tid = avalanche_tid
        if terrain_start_zone_tid is not None:
            self.terrain_start_zone_tid = terrain_start_zone_tid
        if utm_zone_stop is not None:
            self.utm_zone_stop = utm_zone_stop
        if utm_east_stop is not None:
            self.utm_east_stop = utm_east_stop
        if utm_north_stop is not None:
            self.utm_north_stop = utm_north_stop
        if utm_east_start is not None:
            self.utm_east_start = utm_east_start
        if snow_line is not None:
            self.snow_line = snow_line
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if aval_cause_tid is not None:
            self.aval_cause_tid = aval_cause_tid
        if fracture_height is not None:
            self.fracture_height = fracture_height
        if fracture_width is not None:
            self.fracture_width = fracture_width
        if trajectory is not None:
            self.trajectory = trajectory
        if start_lat is not None:
            self.start_lat = start_lat
        if start_long is not None:
            self.start_long = start_long
        if stop_lat is not None:
            self.stop_lat = stop_lat
        if stop_long is not None:
            self.stop_long = stop_long
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment
        if utm_north_start is not None:
            self.utm_north_start = utm_north_start

    @property
    def dt_avalanche_time(self):
        """Gets the dt_avalanche_time of this AvalancheObsDto.  # noqa: E501

        Tid da skredet gikk. DtAvalancheTime  # noqa: E501

        :return: The dt_avalanche_time of this AvalancheObsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_avalanche_time

    @dt_avalanche_time.setter
    def dt_avalanche_time(self, dt_avalanche_time):
        """Sets the dt_avalanche_time of this AvalancheObsDto.

        Tid da skredet gikk. DtAvalancheTime  # noqa: E501

        :param dt_avalanche_time: The dt_avalanche_time of this AvalancheObsDto.  # noqa: E501
        :type: datetime
        """
        if dt_avalanche_time is None:
            raise ValueError("Invalid value for `dt_avalanche_time`, must not be `None`")  # noqa: E501

        self._dt_avalanche_time = dt_avalanche_time

    @property
    def aspect(self):
        """Gets the aspect of this AvalancheObsDto.  # noqa: E501

        Eksposisjon  # noqa: E501

        :return: The aspect of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this AvalancheObsDto.

        Eksposisjon  # noqa: E501

        :param aspect: The aspect of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._aspect = aspect

    @property
    def height_start_zone(self):
        """Gets the height_start_zone of this AvalancheObsDto.  # noqa: E501

        Høyde i løsneområde  # noqa: E501

        :return: The height_start_zone of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._height_start_zone

    @height_start_zone.setter
    def height_start_zone(self, height_start_zone):
        """Sets the height_start_zone of this AvalancheObsDto.

        Høyde i løsneområde  # noqa: E501

        :param height_start_zone: The height_start_zone of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._height_start_zone = height_start_zone

    @property
    def height_stop_zone(self):
        """Gets the height_stop_zone of this AvalancheObsDto.  # noqa: E501

        Høyde i stoppområdet  # noqa: E501

        :return: The height_stop_zone of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._height_stop_zone

    @height_stop_zone.setter
    def height_stop_zone(self, height_stop_zone):
        """Sets the height_stop_zone of this AvalancheObsDto.

        Høyde i stoppområdet  # noqa: E501

        :param height_stop_zone: The height_stop_zone of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._height_stop_zone = height_stop_zone

    @property
    def destructive_size_tid(self):
        """Gets the destructive_size_tid of this AvalancheObsDto.  # noqa: E501

        Størrelse. The DestructiveSizeKD unique identifier  # noqa: E501

        :return: The destructive_size_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_tid

    @destructive_size_tid.setter
    def destructive_size_tid(self, destructive_size_tid):
        """Sets the destructive_size_tid of this AvalancheObsDto.

        Størrelse. The DestructiveSizeKD unique identifier  # noqa: E501

        :param destructive_size_tid: The destructive_size_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._destructive_size_tid = destructive_size_tid

    @property
    def avalanche_trigger_tid(self):
        """Gets the avalanche_trigger_tid of this AvalancheObsDto.  # noqa: E501

        Skredutløser. The AvalancheTriggerKD unique identifier  # noqa: E501

        :return: The avalanche_trigger_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_trigger_tid

    @avalanche_trigger_tid.setter
    def avalanche_trigger_tid(self, avalanche_trigger_tid):
        """Sets the avalanche_trigger_tid of this AvalancheObsDto.

        Skredutløser. The AvalancheTriggerKD unique identifier  # noqa: E501

        :param avalanche_trigger_tid: The avalanche_trigger_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._avalanche_trigger_tid = avalanche_trigger_tid

    @property
    def avalanche_tid(self):
        """Gets the avalanche_tid of this AvalancheObsDto.  # noqa: E501

        Skredtype. The AvalancheKD unique identifier  # noqa: E501

        :return: The avalanche_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_tid

    @avalanche_tid.setter
    def avalanche_tid(self, avalanche_tid):
        """Sets the avalanche_tid of this AvalancheObsDto.

        Skredtype. The AvalancheKD unique identifier  # noqa: E501

        :param avalanche_tid: The avalanche_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._avalanche_tid = avalanche_tid

    @property
    def terrain_start_zone_tid(self):
        """Gets the terrain_start_zone_tid of this AvalancheObsDto.  # noqa: E501

        Terrengtype i løsneområdet. The TerrainStartZoneKD unique identifier  # noqa: E501

        :return: The terrain_start_zone_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._terrain_start_zone_tid

    @terrain_start_zone_tid.setter
    def terrain_start_zone_tid(self, terrain_start_zone_tid):
        """Sets the terrain_start_zone_tid of this AvalancheObsDto.

        Terrengtype i løsneområdet. The TerrainStartZoneKD unique identifier  # noqa: E501

        :param terrain_start_zone_tid: The terrain_start_zone_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._terrain_start_zone_tid = terrain_start_zone_tid

    @property
    def utm_zone_stop(self):
        """Gets the utm_zone_stop of this AvalancheObsDto.  # noqa: E501

        UTMZoneStop  # noqa: E501

        :return: The utm_zone_stop of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone_stop

    @utm_zone_stop.setter
    def utm_zone_stop(self, utm_zone_stop):
        """Sets the utm_zone_stop of this AvalancheObsDto.

        UTMZoneStop  # noqa: E501

        :param utm_zone_stop: The utm_zone_stop of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._utm_zone_stop = utm_zone_stop

    @property
    def utm_east_stop(self):
        """Gets the utm_east_stop of this AvalancheObsDto.  # noqa: E501

        UTMEastStop  # noqa: E501

        :return: The utm_east_stop of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_stop

    @utm_east_stop.setter
    def utm_east_stop(self, utm_east_stop):
        """Sets the utm_east_stop of this AvalancheObsDto.

        UTMEastStop  # noqa: E501

        :param utm_east_stop: The utm_east_stop of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._utm_east_stop = utm_east_stop

    @property
    def utm_north_stop(self):
        """Gets the utm_north_stop of this AvalancheObsDto.  # noqa: E501

        UTMNorthStop  # noqa: E501

        :return: The utm_north_stop of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_stop

    @utm_north_stop.setter
    def utm_north_stop(self, utm_north_stop):
        """Sets the utm_north_stop of this AvalancheObsDto.

        UTMNorthStop  # noqa: E501

        :param utm_north_stop: The utm_north_stop of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._utm_north_stop = utm_north_stop

    @property
    def utm_east_start(self):
        """Gets the utm_east_start of this AvalancheObsDto.  # noqa: E501

        UTMEastStart  # noqa: E501

        :return: The utm_east_start of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_start

    @utm_east_start.setter
    def utm_east_start(self, utm_east_start):
        """Sets the utm_east_start of this AvalancheObsDto.

        UTMEastStart  # noqa: E501

        :param utm_east_start: The utm_east_start of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._utm_east_start = utm_east_start

    @property
    def snow_line(self):
        """Gets the snow_line of this AvalancheObsDto.  # noqa: E501

        SnowLine  # noqa: E501

        :return: The snow_line of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._snow_line

    @snow_line.setter
    def snow_line(self, snow_line):
        """Sets the snow_line of this AvalancheObsDto.

        SnowLine  # noqa: E501

        :param snow_line: The snow_line of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._snow_line = snow_line

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheObsDto.  # noqa: E501

        ValidExposition  # noqa: E501

        :return: The valid_exposition of this AvalancheObsDto.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheObsDto.

        ValidExposition  # noqa: E501

        :param valid_exposition: The valid_exposition of this AvalancheObsDto.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def aval_cause_tid(self):
        """Gets the aval_cause_tid of this AvalancheObsDto.  # noqa: E501

        Skredutløser. The AvalCauseTID unique identifier  # noqa: E501

        :return: The aval_cause_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_tid

    @aval_cause_tid.setter
    def aval_cause_tid(self, aval_cause_tid):
        """Sets the aval_cause_tid of this AvalancheObsDto.

        Skredutløser. The AvalCauseTID unique identifier  # noqa: E501

        :param aval_cause_tid: The aval_cause_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._aval_cause_tid = aval_cause_tid

    @property
    def fracture_height(self):
        """Gets the fracture_height of this AvalancheObsDto.  # noqa: E501

        Bruddhøyde  # noqa: E501

        :return: The fracture_height of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._fracture_height

    @fracture_height.setter
    def fracture_height(self, fracture_height):
        """Sets the fracture_height of this AvalancheObsDto.

        Bruddhøyde  # noqa: E501

        :param fracture_height: The fracture_height of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._fracture_height = fracture_height

    @property
    def fracture_width(self):
        """Gets the fracture_width of this AvalancheObsDto.  # noqa: E501

        Bruddbredde  # noqa: E501

        :return: The fracture_width of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._fracture_width

    @fracture_width.setter
    def fracture_width(self, fracture_width):
        """Sets the fracture_width of this AvalancheObsDto.

        Bruddbredde  # noqa: E501

        :param fracture_width: The fracture_width of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._fracture_width = fracture_width

    @property
    def trajectory(self):
        """Gets the trajectory of this AvalancheObsDto.  # noqa: E501

        Skredbanenavn  # noqa: E501

        :return: The trajectory of this AvalancheObsDto.  # noqa: E501
        :rtype: str
        """
        return self._trajectory

    @trajectory.setter
    def trajectory(self, trajectory):
        """Sets the trajectory of this AvalancheObsDto.

        Skredbanenavn  # noqa: E501

        :param trajectory: The trajectory of this AvalancheObsDto.  # noqa: E501
        :type: str
        """

        self._trajectory = trajectory

    @property
    def start_lat(self):
        """Gets the start_lat of this AvalancheObsDto.  # noqa: E501

        StartLat  # noqa: E501

        :return: The start_lat of this AvalancheObsDto.  # noqa: E501
        :rtype: float
        """
        return self._start_lat

    @start_lat.setter
    def start_lat(self, start_lat):
        """Sets the start_lat of this AvalancheObsDto.

        StartLat  # noqa: E501

        :param start_lat: The start_lat of this AvalancheObsDto.  # noqa: E501
        :type: float
        """

        self._start_lat = start_lat

    @property
    def start_long(self):
        """Gets the start_long of this AvalancheObsDto.  # noqa: E501

        StartLong  # noqa: E501

        :return: The start_long of this AvalancheObsDto.  # noqa: E501
        :rtype: float
        """
        return self._start_long

    @start_long.setter
    def start_long(self, start_long):
        """Sets the start_long of this AvalancheObsDto.

        StartLong  # noqa: E501

        :param start_long: The start_long of this AvalancheObsDto.  # noqa: E501
        :type: float
        """

        self._start_long = start_long

    @property
    def stop_lat(self):
        """Gets the stop_lat of this AvalancheObsDto.  # noqa: E501

        StopLat  # noqa: E501

        :return: The stop_lat of this AvalancheObsDto.  # noqa: E501
        :rtype: float
        """
        return self._stop_lat

    @stop_lat.setter
    def stop_lat(self, stop_lat):
        """Sets the stop_lat of this AvalancheObsDto.

        StopLat  # noqa: E501

        :param stop_lat: The stop_lat of this AvalancheObsDto.  # noqa: E501
        :type: float
        """

        self._stop_lat = stop_lat

    @property
    def stop_long(self):
        """Gets the stop_long of this AvalancheObsDto.  # noqa: E501

        StopLong  # noqa: E501

        :return: The stop_long of this AvalancheObsDto.  # noqa: E501
        :rtype: float
        """
        return self._stop_long

    @stop_long.setter
    def stop_long(self, stop_long):
        """Sets the stop_long of this AvalancheObsDto.

        StopLong  # noqa: E501

        :param stop_long: The stop_long of this AvalancheObsDto.  # noqa: E501
        :type: float
        """

        self._stop_long = stop_long

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this AvalancheObsDto.  # noqa: E501

        UsageFlagKDV  # noqa: E501

        :return: The usage_flag_tid of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this AvalancheObsDto.

        UsageFlagKDV  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this AvalancheObsDto.  # noqa: E501

        Comment  # noqa: E501

        :return: The comment of this AvalancheObsDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheObsDto.

        Comment  # noqa: E501

        :param comment: The comment of this AvalancheObsDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def utm_north_start(self):
        """Gets the utm_north_start of this AvalancheObsDto.  # noqa: E501


        :return: The utm_north_start of this AvalancheObsDto.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_start

    @utm_north_start.setter
    def utm_north_start(self, utm_north_start):
        """Sets the utm_north_start of this AvalancheObsDto.


        :param utm_north_start: The utm_north_start of this AvalancheObsDto.  # noqa: E501
        :type: int
        """

        self._utm_north_start = utm_north_start

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheObsDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheObsDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class IceThicknessDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'snow_depth': 'float',
        'slush_snow': 'float',
        'ice_thickness_sum': 'float',
        'ice_height_before': 'float',
        'ice_height_after': 'float',
        'usage_flag_tid': 'int',
        'comment': 'str',
        'ice_thickness_layer': 'list[IceThicknessLayerDto]'
    }

    attribute_map = {
        'snow_depth': 'SnowDepth',
        'slush_snow': 'SlushSnow',
        'ice_thickness_sum': 'IceThicknessSum',
        'ice_height_before': 'IceHeightBefore',
        'ice_height_after': 'IceHeightAfter',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment',
        'ice_thickness_layer': 'IceThicknessLayer'
    }

    def __init__(self, snow_depth=None, slush_snow=None, ice_thickness_sum=None, ice_height_before=None, ice_height_after=None, usage_flag_tid=None, comment=None, ice_thickness_layer=None):  # noqa: E501
        """IceThicknessDto - a model defined in Swagger"""  # noqa: E501
        self._snow_depth = None
        self._slush_snow = None
        self._ice_thickness_sum = None
        self._ice_height_before = None
        self._ice_height_after = None
        self._usage_flag_tid = None
        self._comment = None
        self._ice_thickness_layer = None
        self.discriminator = None
        if snow_depth is not None:
            self.snow_depth = snow_depth
        if slush_snow is not None:
            self.slush_snow = slush_snow
        if ice_thickness_sum is not None:
            self.ice_thickness_sum = ice_thickness_sum
        if ice_height_before is not None:
            self.ice_height_before = ice_height_before
        if ice_height_after is not None:
            self.ice_height_after = ice_height_after
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment
        if ice_thickness_layer is not None:
            self.ice_thickness_layer = ice_thickness_layer

    @property
    def snow_depth(self):
        """Gets the snow_depth of this IceThicknessDto.  # noqa: E501

        Mengden tørr snø oppå isen. Verdi i meter [m].  # noqa: E501

        :return: The snow_depth of this IceThicknessDto.  # noqa: E501
        :rtype: float
        """
        return self._snow_depth

    @snow_depth.setter
    def snow_depth(self, snow_depth):
        """Sets the snow_depth of this IceThicknessDto.

        Mengden tørr snø oppå isen. Verdi i meter [m].  # noqa: E501

        :param snow_depth: The snow_depth of this IceThicknessDto.  # noqa: E501
        :type: float
        """

        self._snow_depth = snow_depth

    @property
    def slush_snow(self):
        """Gets the slush_snow of this IceThicknessDto.  # noqa: E501

        Mengden sørpe oppå isen. Verdi i meter [m].  # noqa: E501

        :return: The slush_snow of this IceThicknessDto.  # noqa: E501
        :rtype: float
        """
        return self._slush_snow

    @slush_snow.setter
    def slush_snow(self, slush_snow):
        """Sets the slush_snow of this IceThicknessDto.

        Mengden sørpe oppå isen. Verdi i meter [m].  # noqa: E501

        :param slush_snow: The slush_snow of this IceThicknessDto.  # noqa: E501
        :type: float
        """

        self._slush_snow = slush_snow

    @property
    def ice_thickness_sum(self):
        """Gets the ice_thickness_sum of this IceThicknessDto.  # noqa: E501

        Total istykkelse. I tabellen IceThicknessLayer kan individuelle islag registreres. Summen av dem skal samsvare med IceThickenssSum. Verdi i meter [m].  # noqa: E501

        :return: The ice_thickness_sum of this IceThicknessDto.  # noqa: E501
        :rtype: float
        """
        return self._ice_thickness_sum

    @ice_thickness_sum.setter
    def ice_thickness_sum(self, ice_thickness_sum):
        """Sets the ice_thickness_sum of this IceThicknessDto.

        Total istykkelse. I tabellen IceThicknessLayer kan individuelle islag registreres. Summen av dem skal samsvare med IceThickenssSum. Verdi i meter [m].  # noqa: E501

        :param ice_thickness_sum: The ice_thickness_sum of this IceThicknessDto.  # noqa: E501
        :type: float
        """

        self._ice_thickness_sum = ice_thickness_sum

    @property
    def ice_height_before(self):
        """Gets the ice_height_before of this IceThicknessDto.  # noqa: E501

        Isen kan være presset under vannspeilet eller flyte oppå. Her registreres denne høyden før borring. IceHeightBefore = 0 betyr at isen er tørr og negative verdier angir overvann. Verdi i meter [m].  # noqa: E501

        :return: The ice_height_before of this IceThicknessDto.  # noqa: E501
        :rtype: float
        """
        return self._ice_height_before

    @ice_height_before.setter
    def ice_height_before(self, ice_height_before):
        """Sets the ice_height_before of this IceThicknessDto.

        Isen kan være presset under vannspeilet eller flyte oppå. Her registreres denne høyden før borring. IceHeightBefore = 0 betyr at isen er tørr og negative verdier angir overvann. Verdi i meter [m].  # noqa: E501

        :param ice_height_before: The ice_height_before of this IceThicknessDto.  # noqa: E501
        :type: float
        """

        self._ice_height_before = ice_height_before

    @property
    def ice_height_after(self):
        """Gets the ice_height_after of this IceThicknessDto.  # noqa: E501

        Isen kan være presset under vannspeilet eller flyte oppå. Her registreres denne høyden etter borring. IPositive verdier angir at vannet står nedi hulet og og negative verdier angir overvann. Verdi i meter [m].  # noqa: E501

        :return: The ice_height_after of this IceThicknessDto.  # noqa: E501
        :rtype: float
        """
        return self._ice_height_after

    @ice_height_after.setter
    def ice_height_after(self, ice_height_after):
        """Sets the ice_height_after of this IceThicknessDto.

        Isen kan være presset under vannspeilet eller flyte oppå. Her registreres denne høyden etter borring. IPositive verdier angir at vannet står nedi hulet og og negative verdier angir overvann. Verdi i meter [m].  # noqa: E501

        :param ice_height_after: The ice_height_after of this IceThicknessDto.  # noqa: E501
        :type: float
        """

        self._ice_height_after = ice_height_after

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this IceThicknessDto.  # noqa: E501

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :return: The usage_flag_tid of this IceThicknessDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this IceThicknessDto.

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this IceThicknessDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this IceThicknessDto.  # noqa: E501

        Comment  # noqa: E501

        :return: The comment of this IceThicknessDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this IceThicknessDto.

        Comment  # noqa: E501

        :param comment: The comment of this IceThicknessDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def ice_thickness_layer(self):
        """Gets the ice_thickness_layer of this IceThicknessDto.  # noqa: E501

        Provide description for IceThicknessLayer  # noqa: E501

        :return: The ice_thickness_layer of this IceThicknessDto.  # noqa: E501
        :rtype: list[IceThicknessLayerDto]
        """
        return self._ice_thickness_layer

    @ice_thickness_layer.setter
    def ice_thickness_layer(self, ice_thickness_layer):
        """Sets the ice_thickness_layer of this IceThicknessDto.

        Provide description for IceThicknessLayer  # noqa: E501

        :param ice_thickness_layer: The ice_thickness_layer of this IceThicknessDto.  # noqa: E501
        :type: list[IceThicknessLayerDto]
        """

        self._ice_thickness_layer = ice_thickness_layer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IceThicknessDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IceThicknessDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DamageObsViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'geo_hazard_tid': 'int',
        'geo_hazard_name': 'str',
        'damage_type_tid': 'int',
        'damage_type_name': 'str',
        'damage_position': 'PositionDto',
        'comment': 'str',
        'attachments': 'list[int]'
    }

    attribute_map = {
        'geo_hazard_tid': 'GeoHazardTID',
        'geo_hazard_name': 'GeoHazardName',
        'damage_type_tid': 'DamageTypeTID',
        'damage_type_name': 'DamageTypeName',
        'damage_position': 'DamagePosition',
        'comment': 'Comment',
        'attachments': 'Attachments'
    }

    def __init__(self, geo_hazard_tid=None, geo_hazard_name=None, damage_type_tid=None, damage_type_name=None, damage_position=None, comment=None, attachments=None):  # noqa: E501
        """DamageObsViewModel - a model defined in Swagger"""  # noqa: E501
        self._geo_hazard_tid = None
        self._geo_hazard_name = None
        self._damage_type_tid = None
        self._damage_type_name = None
        self._damage_position = None
        self._comment = None
        self._attachments = None
        self.discriminator = None
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if geo_hazard_name is not None:
            self.geo_hazard_name = geo_hazard_name
        if damage_type_tid is not None:
            self.damage_type_tid = damage_type_tid
        if damage_type_name is not None:
            self.damage_type_name = damage_type_name
        if damage_position is not None:
            self.damage_position = damage_position
        if comment is not None:
            self.comment = comment
        if attachments is not None:
            self.attachments = attachments

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this DamageObsViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this DamageObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this DamageObsViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this DamageObsViewModel.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def geo_hazard_name(self):
        """Gets the geo_hazard_name of this DamageObsViewModel.  # noqa: E501


        :return: The geo_hazard_name of this DamageObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._geo_hazard_name

    @geo_hazard_name.setter
    def geo_hazard_name(self, geo_hazard_name):
        """Sets the geo_hazard_name of this DamageObsViewModel.


        :param geo_hazard_name: The geo_hazard_name of this DamageObsViewModel.  # noqa: E501
        :type: str
        """

        self._geo_hazard_name = geo_hazard_name

    @property
    def damage_type_tid(self):
        """Gets the damage_type_tid of this DamageObsViewModel.  # noqa: E501


        :return: The damage_type_tid of this DamageObsViewModel.  # noqa: E501
        :rtype: int
        """
        return self._damage_type_tid

    @damage_type_tid.setter
    def damage_type_tid(self, damage_type_tid):
        """Sets the damage_type_tid of this DamageObsViewModel.


        :param damage_type_tid: The damage_type_tid of this DamageObsViewModel.  # noqa: E501
        :type: int
        """

        self._damage_type_tid = damage_type_tid

    @property
    def damage_type_name(self):
        """Gets the damage_type_name of this DamageObsViewModel.  # noqa: E501


        :return: The damage_type_name of this DamageObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._damage_type_name

    @damage_type_name.setter
    def damage_type_name(self, damage_type_name):
        """Sets the damage_type_name of this DamageObsViewModel.


        :param damage_type_name: The damage_type_name of this DamageObsViewModel.  # noqa: E501
        :type: str
        """

        self._damage_type_name = damage_type_name

    @property
    def damage_position(self):
        """Gets the damage_position of this DamageObsViewModel.  # noqa: E501


        :return: The damage_position of this DamageObsViewModel.  # noqa: E501
        :rtype: PositionDto
        """
        return self._damage_position

    @damage_position.setter
    def damage_position(self, damage_position):
        """Sets the damage_position of this DamageObsViewModel.


        :param damage_position: The damage_position of this DamageObsViewModel.  # noqa: E501
        :type: PositionDto
        """

        self._damage_position = damage_position

    @property
    def comment(self):
        """Gets the comment of this DamageObsViewModel.  # noqa: E501


        :return: The comment of this DamageObsViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this DamageObsViewModel.


        :param comment: The comment of this DamageObsViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def attachments(self):
        """Gets the attachments of this DamageObsViewModel.  # noqa: E501


        :return: The attachments of this DamageObsViewModel.  # noqa: E501
        :rtype: list[int]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this DamageObsViewModel.


        :param attachments: The attachments of this DamageObsViewModel.  # noqa: E501
        :type: list[int]
        """

        self._attachments = attachments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DamageObsViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DamageObsViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CompressionTestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'compression_test_tid': 'int',
        'taps_fracture': 'int',
        'taps_full_propagation': 'int',
        'propagation_tid': 'int',
        'fracture_depth': 'float',
        'stability_eval_tid': 'int',
        'usage_flag_tid': 'int',
        'compr_test_fracture_tid': 'int',
        'comment': 'str',
        'include_in_snow_profile': 'bool'
    }

    attribute_map = {
        'compression_test_tid': 'CompressionTestTID',
        'taps_fracture': 'TapsFracture',
        'taps_full_propagation': 'TapsFullPropagation',
        'propagation_tid': 'PropagationTID',
        'fracture_depth': 'FractureDepth',
        'stability_eval_tid': 'StabilityEvalTID',
        'usage_flag_tid': 'UsageFlagTID',
        'compr_test_fracture_tid': 'ComprTestFractureTID',
        'comment': 'Comment',
        'include_in_snow_profile': 'IncludeInSnowProfile'
    }

    def __init__(self, compression_test_tid=None, taps_fracture=None, taps_full_propagation=None, propagation_tid=None, fracture_depth=None, stability_eval_tid=None, usage_flag_tid=None, compr_test_fracture_tid=None, comment=None, include_in_snow_profile=None):  # noqa: E501
        """CompressionTestDto - a model defined in Swagger"""  # noqa: E501
        self._compression_test_tid = None
        self._taps_fracture = None
        self._taps_full_propagation = None
        self._propagation_tid = None
        self._fracture_depth = None
        self._stability_eval_tid = None
        self._usage_flag_tid = None
        self._compr_test_fracture_tid = None
        self._comment = None
        self._include_in_snow_profile = None
        self.discriminator = None
        if compression_test_tid is not None:
            self.compression_test_tid = compression_test_tid
        if taps_fracture is not None:
            self.taps_fracture = taps_fracture
        if taps_full_propagation is not None:
            self.taps_full_propagation = taps_full_propagation
        if propagation_tid is not None:
            self.propagation_tid = propagation_tid
        if fracture_depth is not None:
            self.fracture_depth = fracture_depth
        if stability_eval_tid is not None:
            self.stability_eval_tid = stability_eval_tid
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if compr_test_fracture_tid is not None:
            self.compr_test_fracture_tid = compr_test_fracture_tid
        if comment is not None:
            self.comment = comment
        if include_in_snow_profile is not None:
            self.include_in_snow_profile = include_in_snow_profile

    @property
    def compression_test_tid(self):
        """Gets the compression_test_tid of this CompressionTestDto.  # noqa: E501

        The CompressionTestKDV unique identifier  # noqa: E501

        :return: The compression_test_tid of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._compression_test_tid

    @compression_test_tid.setter
    def compression_test_tid(self, compression_test_tid):
        """Sets the compression_test_tid of this CompressionTestDto.

        The CompressionTestKDV unique identifier  # noqa: E501

        :param compression_test_tid: The compression_test_tid of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._compression_test_tid = compression_test_tid

    @property
    def taps_fracture(self):
        """Gets the taps_fracture of this CompressionTestDto.  # noqa: E501

        TapsFracture  # noqa: E501

        :return: The taps_fracture of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._taps_fracture

    @taps_fracture.setter
    def taps_fracture(self, taps_fracture):
        """Sets the taps_fracture of this CompressionTestDto.

        TapsFracture  # noqa: E501

        :param taps_fracture: The taps_fracture of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._taps_fracture = taps_fracture

    @property
    def taps_full_propagation(self):
        """Gets the taps_full_propagation of this CompressionTestDto.  # noqa: E501

        TapsFullPropagation  # noqa: E501

        :return: The taps_full_propagation of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._taps_full_propagation

    @taps_full_propagation.setter
    def taps_full_propagation(self, taps_full_propagation):
        """Sets the taps_full_propagation of this CompressionTestDto.

        TapsFullPropagation  # noqa: E501

        :param taps_full_propagation: The taps_full_propagation of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._taps_full_propagation = taps_full_propagation

    @property
    def propagation_tid(self):
        """Gets the propagation_tid of this CompressionTestDto.  # noqa: E501

        The PropagationKD unique identifier  # noqa: E501

        :return: The propagation_tid of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._propagation_tid

    @propagation_tid.setter
    def propagation_tid(self, propagation_tid):
        """Sets the propagation_tid of this CompressionTestDto.

        The PropagationKD unique identifier  # noqa: E501

        :param propagation_tid: The propagation_tid of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._propagation_tid = propagation_tid

    @property
    def fracture_depth(self):
        """Gets the fracture_depth of this CompressionTestDto.  # noqa: E501

        FractureDepth  # noqa: E501

        :return: The fracture_depth of this CompressionTestDto.  # noqa: E501
        :rtype: float
        """
        return self._fracture_depth

    @fracture_depth.setter
    def fracture_depth(self, fracture_depth):
        """Sets the fracture_depth of this CompressionTestDto.

        FractureDepth  # noqa: E501

        :param fracture_depth: The fracture_depth of this CompressionTestDto.  # noqa: E501
        :type: float
        """

        self._fracture_depth = fracture_depth

    @property
    def stability_eval_tid(self):
        """Gets the stability_eval_tid of this CompressionTestDto.  # noqa: E501

        The StabilityEvalKD unique identifier  # noqa: E501

        :return: The stability_eval_tid of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._stability_eval_tid

    @stability_eval_tid.setter
    def stability_eval_tid(self, stability_eval_tid):
        """Sets the stability_eval_tid of this CompressionTestDto.

        The StabilityEvalKD unique identifier  # noqa: E501

        :param stability_eval_tid: The stability_eval_tid of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._stability_eval_tid = stability_eval_tid

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this CompressionTestDto.  # noqa: E501

        The UsageFlagKD unique identifier  # noqa: E501

        :return: The usage_flag_tid of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this CompressionTestDto.

        The UsageFlagKD unique identifier  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def compr_test_fracture_tid(self):
        """Gets the compr_test_fracture_tid of this CompressionTestDto.  # noqa: E501

        The ComprTestFractureKD unique identifier  # noqa: E501

        :return: The compr_test_fracture_tid of this CompressionTestDto.  # noqa: E501
        :rtype: int
        """
        return self._compr_test_fracture_tid

    @compr_test_fracture_tid.setter
    def compr_test_fracture_tid(self, compr_test_fracture_tid):
        """Sets the compr_test_fracture_tid of this CompressionTestDto.

        The ComprTestFractureKD unique identifier  # noqa: E501

        :param compr_test_fracture_tid: The compr_test_fracture_tid of this CompressionTestDto.  # noqa: E501
        :type: int
        """

        self._compr_test_fracture_tid = compr_test_fracture_tid

    @property
    def comment(self):
        """Gets the comment of this CompressionTestDto.  # noqa: E501

        Comment  # noqa: E501

        :return: The comment of this CompressionTestDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this CompressionTestDto.

        Comment  # noqa: E501

        :param comment: The comment of this CompressionTestDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def include_in_snow_profile(self):
        """Gets the include_in_snow_profile of this CompressionTestDto.  # noqa: E501

        Include in snow profile  # noqa: E501

        :return: The include_in_snow_profile of this CompressionTestDto.  # noqa: E501
        :rtype: bool
        """
        return self._include_in_snow_profile

    @include_in_snow_profile.setter
    def include_in_snow_profile(self, include_in_snow_profile):
        """Sets the include_in_snow_profile of this CompressionTestDto.

        Include in snow profile  # noqa: E501

        :param include_in_snow_profile: The include_in_snow_profile of this CompressionTestDto.  # noqa: E501
        :type: bool
        """

        self._include_in_snow_profile = include_in_snow_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompressionTestDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressionTestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
